/* global Jodit, toggleElementClass */

const agentTextEditor = {
  agentInputContainer: null,
  currentlyDisabled: false,
  editor: null,
  setup(submissionEvent) {
    this.agentInputContainer = document.getElementById("agent_input_container");
    const joditElement = document.getElementById("jodit");
    this.editor = new Jodit("#jodit", {
      minHeight: 100,
      height: "100%",
      allowResizeY: false,
      askBeforePasteHTML: false,
      askBeforePasteFromWord: false,
      defaultActionOnPaste: "insert_clear_html",
      cleanHTML: {
        denyTags: {
          img: "image",
        },
      },
      showCharsCounter: false,
      showWordsCounter: false,
      showXPathInStatusbar: false,
      link: {
        followOnDblClick: false,
        processVideoLink: false,
        noFollowCheckbox: false,
        openInNewTabCheckbox: false,
      },
      popup: {
        a: Jodit.Array(["unlink"]),
      },
      uploader: {
        insertImageAsBase64URI: false,
      },
      disablePlugins: "imageprocessor,imageproperties,enter",
      enter: "br",
      toolbar: true,
      toolbarAdaptive: false,
      buttons: ["bold", "italic", "underline", "|", "brush"],
      readonly: false,
    });
    this.addEventListener("keydown", (keyEvent) => {
      if (keyEvent.key === "Enter" && !keyEvent.shiftKey && !this.currentlyDisabled) {
        keyEvent.preventDefault();
        submissionEvent();
      }
    });
    joditElement.hidden = false;
    this.editor.value = "";
    this.toggleEditorToolbar();
    this.enable();
  },
  addEventListener(keyEventType, event) {
    this.agentInputContainer.addEventListener(keyEventType, event);
  },
  toggleEditorToolbar() {
    const button = document.getElementById("toggle_rich_text_button");
    toggleElementClass(button, "hide_text");
    const toolbar = agentTextEditor.editor.toolbar.container;
    toggleElementClass(toolbar, "hidden");
  },
  _readOnlyClassToggleElements: ["public_response", "translate_label", "agent_input_container"],
  _readOnlyDisableToggleElements: ["toggle_rich_text_button", "translate_checkbox", "send_button"],
  disable() {
    this.currentlyDisabled = true;
    agentTextEditor.editor.setReadOnly(true);
    this._readOnlyClassToggleElements.forEach((element) => {
      document.getElementById(element).classList.add("disabled");
    });
    this._readOnlyDisableToggleElements.forEach((element) => {
      document.getElementById(element).disabled = true;
    });
  },
  enable() {
    this.currentlyDisabled = false;
    agentTextEditor.editor.setReadOnly(false);
    this._readOnlyClassToggleElements.forEach((element) => {
      document.getElementById(element).classList.remove("disabled");
    });
    this._readOnlyDisableToggleElements.forEach((element) => {
      document.getElementById(element).disabled = false;
    });
  },
};
